"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const config_1 = require("@cli-engine/config");
const cli_flags_1 = require("cli-flags");
const command_1 = require("./command");
const deps_1 = require("./deps");
const help_1 = require("./help");
class Command extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return;
        });
    }
}
deps_1.default.cli.config.mock = true;
class AppsCreate extends Command {
}
AppsCreate.id = 'apps:create';
AppsCreate.description = 'description of apps:create';
AppsCreate.help = `some

multiline help
`;
AppsCreate.args = [{ name: 'app_name', description: 'app to use' }];
AppsCreate.flags = {
    app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
    foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
    force: cli_flags_1.flags.boolean({ description: 'force it' }),
    remote: cli_flags_1.flags.string({ char: 'r' }),
};
const help = new help_1.Help(new config_1.Config());
describe('commandLine()', () => {
    test('has help', () => {
        expect(help.command(AppsCreate)).toEqual(`Usage: cli-engine apps:create [APP_NAME] [flags]

description of apps:create

APP_NAME  app to use

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it

some

multiline help
`);
    });
    class AppsCreate3 extends Command {
    }
    AppsCreate3.id = 'apps:create';
    AppsCreate3.flags = {
        app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
        foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
        force: cli_flags_1.flags.boolean({ description: 'force it' }),
        remote: cli_flags_1.flags.string({ char: 'r' }),
    };
    test('has just flags', () => {
        expect(help.command(AppsCreate3)).toEqual(`Usage: cli-engine apps:create [flags]

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it
`);
    });
    test('has flags + description', () => {
        class CMD extends Command {
        }
        CMD.id = 'apps:create';
        CMD.description = 'description of apps:create';
        CMD.flags = {
            app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
            foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
            force: cli_flags_1.flags.boolean({ description: 'force it' }),
            remote: cli_flags_1.flags.string({ char: 'r' }),
        };
        expect(help.command(CMD)).toEqual(`Usage: cli-engine apps:create [flags]

description of apps:create

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it
`);
    });
    class AppsCreate1 extends Command {
    }
    AppsCreate1.id = 'apps:create';
    AppsCreate1.help = 'description of apps:create';
    AppsCreate1.flags = {
        app: cli_flags_1.flags.string({ char: 'a', hidden: true }),
        foo: cli_flags_1.flags.string({ char: 'f', description: 'foobar' }),
        force: cli_flags_1.flags.boolean({ description: 'force it' }),
        remote: cli_flags_1.flags.string({ char: 'r' }),
    };
    test('has description + help', () => {
        expect(help.command(AppsCreate1)).toEqual(`Usage: cli-engine apps:create [flags]

Flags:
 -f, --foo FOO        foobar
 -r, --remote REMOTE
 --force              force it

description of apps:create
`);
    });
    class AppsCreate2 extends Command {
    }
    AppsCreate2.id = 'apps:create';
    AppsCreate2.description = 'description of apps:create';
    AppsCreate2.args = [{ name: 'app_name', description: 'app to use' }];
    test('has description + args', () => {
        expect(help.command(AppsCreate2)).toEqual(`Usage: cli-engine apps:create [APP_NAME]

description of apps:create

APP_NAME  app to use
`);
    });
    class CMD extends Command {
    }
    CMD.id = 'apps:create2';
    CMD.description = 'description of apps:create2';
    CMD.args = [{ name: 'app_name', description: 'app to use' }];
    CMD.aliases = ['foo', 'bar'];
    test('has aliases', () => {
        expect(help.command(CMD)).toEqual(`Usage: cli-engine apps:create2 [APP_NAME]

description of apps:create2

Aliases:
  $ cli-engine foo
  $ cli-engine bar

APP_NAME  app to use
`);
    });
});
describe('command()', () => {
    test('has command help', () => {
        expect(help.commandLine(AppsCreate)).toEqual(['apps:create [APP_NAME]', 'description of apps:create']);
    });
});
